********************
API Reference
********************

Oct2Py
------
.. module:: oct2py
.. autoclass:: Oct2Py
   :members:

Struct
------
.. autoclass:: Struct

Cell
----
.. autoclass:: Cell

StructArray
-----------
.. autoclass:: StructArray

Oct2PyError
-----------
.. autoclass:: Oct2PyError

get_log
-------
.. autofunction:: get_log

kill_octave
-----------
.. autofunction:: kill_octave
